==> hadoop-client-api-3.2.4-sources.jar: org/apache/hadoop/yarn/api/protocolrecords/impl/pb/RenewDelegationTokenResponsePBImpl.java <==
/**
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements. See the NOTICE file distributed with this
 * work for additional information regarding copyright ownership. The ASF
 * licenses this file to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in org.apache.hadoop.shaded.com.liance with the License.
 * You may obtain a copy of the License at
 * 
 * http://www.apache.org.apache.hadoop.shaded.org.licenses/LICENSE-2.0
 * 
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS, WITHOUT
 * WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
 * License for the specific language governing permissions and limitations under
 * the License.
 */

package org.apache.hadoop.shaded.org.apache.hadoop.yarn.api.protocolrecords.impl.pb;

import org.apache.hadoop.shaded.org.apache.hadoop.classification.InterfaceAudience.Private;
import org.apache.hadoop.shaded.org.apache.hadoop.classification.InterfaceStability.Unstable;
import org.apache.hadoop.shaded.org.apache.hadoop.security.proto.SecurityProtos.RenewDelegationTokenResponseProto;
import org.apache.hadoop.shaded.org.apache.hadoop.security.proto.SecurityProtos.RenewDelegationTokenResponseProtoOrBuilder;
import org.apache.hadoop.shaded.org.apache.hadoop.yarn.api.protocolrecords.RenewDelegationTokenResponse;

import org.apache.hadoop.shaded.com.google.protobuf.TextFormat;

@Private
@Unstable
public class RenewDelegationTokenResponsePBImpl extends 
    RenewDelegationTokenResponse {

  RenewDelegationTokenResponseProto proto =
      RenewDelegationTokenResponseProto.getDefaultInstance();
  RenewDelegationTokenResponseProto.Builder builder = null;
  boolean viaProto = false;

  public RenewDelegationTokenResponsePBImpl() {
    this.builder = RenewDelegationTokenResponseProto.newBuilder();
  }

  public RenewDelegationTokenResponsePBImpl (
      RenewDelegationTokenResponseProto proto) {
    this.proto = proto;
    this.viaProto = true;
  }

  public RenewDelegationTokenResponseProto getProto() {
    proto = viaProto ? proto : builder.build();
    viaProto = true;
    return proto;
  }

  @Override
  public int hashCode() {
    return getProto().hashCode();
  }

  @Override
  public boolean equals(Object other) {
    if (other == null)
      return false;
    if (other.getClass().isAssignableFrom(this.getClass())) {
      return this.getProto().equals(this.getClass().cast(other).getProto());
    }
    return false;
  }

  @Override
  public String toString() {
    return TextFormat.shortDebugString(getProto());
  }

  private void maybeInitBuilder() {
    if (viaProto || builder == null) {
      builder = RenewDelegationTokenResponseProto.newBuilder(proto);
    }
    viaProto = false;
  }
  
  @Override
  public long getNextExpirationTime() {
    RenewDelegationTokenResponseProtoOrBuilder p = viaProto ? proto : builder;
    return p.getNewExpiryTime();
  }

  @Override
  public void setNextExpirationTime(long expTime) {
    maybeInitBuilder();
    builder.setNewExpiryTime(expTime);
  }
}

==> hadoop-client-api-3.3.4-sources.jar: org/apache/hadoop/yarn/api/protocolrecords/impl/pb/RenewDelegationTokenResponsePBImpl.java <==
/**
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements. See the NOTICE file distributed with this
 * work for additional information regarding copyright ownership. The ASF
 * licenses this file to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in org.apache.hadoop.shaded.com.liance with the License.
 * You may obtain a copy of the License at
 * 
 * http://www.apache.org.apache.hadoop.shaded.org.licenses/LICENSE-2.0
 * 
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS, WITHOUT
 * WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
 * License for the specific language governing permissions and limitations under
 * the License.
 */

package org.apache.hadoop.shaded.org.apache.hadoop.yarn.api.protocolrecords.impl.pb;

import org.apache.hadoop.shaded.org.apache.hadoop.classification.InterfaceAudience.Private;
import org.apache.hadoop.shaded.org.apache.hadoop.classification.InterfaceStability.Unstable;
import org.apache.hadoop.shaded.org.apache.hadoop.security.proto.SecurityProtos.RenewDelegationTokenResponseProto;
import org.apache.hadoop.shaded.org.apache.hadoop.security.proto.SecurityProtos.RenewDelegationTokenResponseProtoOrBuilder;
import org.apache.hadoop.shaded.org.apache.hadoop.yarn.api.protocolrecords.RenewDelegationTokenResponse;

import org.apache.hadoop.shaded.org.apache.hadoop.thirdparty.protobuf.TextFormat;

@Private
@Unstable
public class RenewDelegationTokenResponsePBImpl extends 
    RenewDelegationTokenResponse {

  RenewDelegationTokenResponseProto proto =
      RenewDelegationTokenResponseProto.getDefaultInstance();
  RenewDelegationTokenResponseProto.Builder builder = null;
  boolean viaProto = false;

  public RenewDelegationTokenResponsePBImpl() {
    this.builder = RenewDelegationTokenResponseProto.newBuilder();
  }

  public RenewDelegationTokenResponsePBImpl (
      RenewDelegationTokenResponseProto proto) {
    this.proto = proto;
    this.viaProto = true;
  }

  public RenewDelegationTokenResponseProto getProto() {
    proto = viaProto ? proto : builder.build();
    viaProto = true;
    return proto;
  }

  @Override
  public int hashCode() {
    return getProto().hashCode();
  }

  @Override
  public boolean equals(Object other) {
    if (other == null)
      return false;
    if (other.getClass().isAssignableFrom(this.getClass())) {
      return this.getProto().equals(this.getClass().cast(other).getProto());
    }
    return false;
  }

  @Override
  public String toString() {
    return TextFormat.shortDebugString(getProto());
  }

  private void maybeInitBuilder() {
    if (viaProto || builder == null) {
      builder = RenewDelegationTokenResponseProto.newBuilder(proto);
    }
    viaProto = false;
  }
  
  @Override
  public long getNextExpirationTime() {
    RenewDelegationTokenResponseProtoOrBuilder p = viaProto ? proto : builder;
    return p.getNewExpiryTime();
  }

  @Override
  public void setNextExpirationTime(long expTime) {
    maybeInitBuilder();
    builder.setNewExpiryTime(expTime);
  }
}
